# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import os

from django.conf import settings
from django.conf.urls.defaults import (
    include, patterns, url, handler404, handler500)

from django.contrib import admin

from djcelery.models import TaskState, WorkerState
from piston.resource import Resource

import offspring.web
from offspring.web.queuemanager.handlers import (
    BuildManifestHandler,
    BuildManifestComparisonHandler,
    BuildResultHandler,
    BuildRequestHandler,
    LaunchpadProjectMilestoneHandler,
    ProjectNotificationSubscriptionHandler,
    ReleaseHandler
)

admin.autodiscover()

# TaskState and WorkerState models will not get created or updated if we're
# using a database as the broker for celery. This is confusing if you're
# unaware of this current limitation so lets not show them in the admin
# interface in this scenario.
if settings.BROKER_TRANSPORT == 'djkombu.transport.DatabaseTransport':
    admin.site.unregister(TaskState)
    admin.site.unregister(WorkerState)

milestone_handler = Resource(LaunchpadProjectMilestoneHandler)
buildrequest_handler = Resource(BuildRequestHandler)
buildresult_handler = Resource(BuildResultHandler)
projectNotificationSubscription_handler = Resource(
    ProjectNotificationSubscriptionHandler)
manifest_handler = Resource(BuildManifestHandler)
manifestComparison_handler = Resource(BuildManifestComparisonHandler)
release_handler = Resource(ReleaseHandler)

urlpatterns = patterns('',
    (r'^admin/', include(admin.site.urls)),
    (r'^openid/', include('django_openid_auth.urls')),
    (r'^logout/', 'django.contrib.auth.views.logout'),
)

urlpatterns += patterns('offspring.web.queuemanager.views',
    url(r'^builders/$', 'builders', name='builder_list'),
    url(r'^builders/(?P<builderName>[^/]+)/$', 'builder_details', name='builder_details'),
    (r'^builders/\+api/(?P<builderName>[^/]+)/builds/$', buildresult_handler),
    (r'^builds/\+api/$', buildresult_handler),
    (r'^builds/\+api/(?P<projectName>[^/]+)/$', buildresult_handler),
    (r'^builds/\+api/(?P<projectName>[^/]+)/(?P<buildName>[^/]+)/$', buildresult_handler),
    (r'^builds/\+api/(?P<projectName>[^/]+)/(?P<buildName>[^/]+)/manifest/\+comparison', manifestComparison_handler),
    (r'^builds/\+api/(?P<projectName>[^/]+)/(?P<buildName>[^/]+)/manifest/$', manifest_handler),
    (r'^builds/(?P<projectName>[^/]+)/(?P<buildName>[^/]+)/\+publish$', 'build_publish'),
    (r'^builds/(?P<projectName>[^/]+)/(?P<buildName>[^/]+)/$', 'build_details'),
    (r'^builds/(?P<projectName>[^/]+)/$', 'builds'),
    (r'^builds/$', 'builds'),
    url(r'^launchpad_project/\+add/$', 'launchpad_project_create',
        name='launchpad_project_create'),
    (r'^project-groups/(?P<projectGroupName>[^/]+)/$', 'projectgroup_details'),
    url(r'^projects/\+add/$', 'project_create', name='project_create'),
    url(r'^projects/(?P<projectName>[^/]+)/\+edit$', 'project_edit', name='project_edit'),
    url(r'^projects/(?P<projectName>[^/]+)/\+acl$', 'project_acl', name='project_acl'),
    (r'^projects/(?P<projectName>[^/]+)/sources\.list$', 'project_development_sourcesList'),
    (r'^projects/(?P<projectName>[^/]+)/\+api/subscription/$', projectNotificationSubscription_handler),
    (r'^projects/(?P<projectName>[^/]+)/\+api/releases/$', release_handler),
    (r'^projects/(?P<projectName>[^/]+)/\+api/buildrequest/$', buildrequest_handler),
    (r'^projects/(?P<projectName>[^/]+)/\+api/buildrequest/(?P<request_id>[^/]+)/$', buildrequest_handler),
    (r'^projects/(?P<projectName>[^/]+)/\+build$', 'queue_build'),
    (r'^projects/(?P<projectName>[^/]+)/\+builds$', 'builds'),
    (r'^projects/(?P<projectName>[^/]+)/$', 'project_details'),
    (r'^projects/$', 'projects'),
    (r'^schedule/\+api/milestones/$', milestone_handler),
    (r'^schedule/\+(?P<milestoneType>[^/]+)-milestones$', 'milestones'),
    (r'^schedule/$', 'schedule'),
    (r'^$', 'projects'),
)

if settings.DEBUG:
    from django.views.decorators.cache import cache_page
    from django.views import static

    urlpatterns += patterns('',
        (r'^assets/(?P<path>.*)$', cache_page(static.serve, 60 * 60 * 24), {
            'document_root': os.path.join(offspring.web.__path__[0], 'media')
            }
        ),
    )
